@@ -1,10 +1,25 @@
+# PyPlexity
+# Copyright (C) 2022 Manuel Prada Corral
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 import datetime
 import io
 import shutil
 import time
 import traceback
 from pathlib import Path
-from typing import Union
 
 import nltk as nltk
 import requests
@@ -16,7 +31,7 @@ from pyplexity.dataset_processor.CustomWARCWriter import CustomWARCWriter
 
 
 class ContentProcessor:
-    def process(self, content: Union[str, bytes]) -> str:
+    def process(self, content: bytes) -> str:
         raise NotImplementedError
 
 
@@ -27,14 +42,14 @@ class DatasetProcessor:
         self.output_dir = Path(output_dir)
         self.content_processor = content_processor
 
-    def batch_process_from_server(self, process_number, port):
+    def batch_process_from_server(self, process_number, url, port):
         print(f"P{process_number} computing warc files...")
-        file = requests.get(f"http://master:{port}/files").text  # get filenames to process from master node REST API
+        file = requests.get(f"http://{url}:{port}/files").text  # get filenames to process from master node REST API
         i = 0
         start = time.time()
         while file != "END":
             self.process_single_file(file, i, process_number, True)
-            file = requests.get(f"http://master:{port}/files").text  # ask for a new WARC file to process
+            file = requests.get(f"http://{url}:{port}/files").text  # ask for a new WARC file to process
             i += 1
         print(f"P{process_number} computed {i} warc files in {str(datetime.timedelta(seconds=time.time() - start))}.")
 
